==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/IPAMConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IPAMConfigBuilder extends IPAMConfigFluentImpl<IPAMConfigBuilder> implements VisitableBuilder<IPAMConfig,IPAMConfigBuilder>{
  public IPAMConfigBuilder() {
    this(false);
  }
  public IPAMConfigBuilder(Boolean validationEnabled) {
    this(new IPAMConfig(), validationEnabled);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IPAMConfig(), validationEnabled);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent,IPAMConfig instance) {
    this(fluent, instance, false);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent,IPAMConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withStaticIPAMConfig(instance.getStaticIPAMConfig());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IPAMConfigBuilder(IPAMConfig instance) {
    this(instance,false);
  }
  public IPAMConfigBuilder(IPAMConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withStaticIPAMConfig(instance.getStaticIPAMConfig());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IPAMConfigFluent<?> fluent;
  Boolean validationEnabled;
  public IPAMConfig build() {
    IPAMConfig buildable = new IPAMConfig(fluent.getStaticIPAMConfig(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IPAMConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IPAMConfigBuilder extends IPAMConfigFluent<IPAMConfigBuilder> implements VisitableBuilder<IPAMConfig,IPAMConfigBuilder>{
  public IPAMConfigBuilder() {
    this(false);
  }
  public IPAMConfigBuilder(Boolean validationEnabled) {
    this(new IPAMConfig(), validationEnabled);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IPAMConfig(), validationEnabled);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent,IPAMConfig instance) {
    this(fluent, instance, false);
  }
  public IPAMConfigBuilder(IPAMConfigFluent<?> fluent,IPAMConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IPAMConfig());

    if (instance != null) {
      fluent.withStaticIPAMConfig(instance.getStaticIPAMConfig());
      fluent.withType(instance.getType());
      fluent.withStaticIPAMConfig(instance.getStaticIPAMConfig());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IPAMConfigBuilder(IPAMConfig instance) {
    this(instance,false);
  }
  public IPAMConfigBuilder(IPAMConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IPAMConfig());

    if (instance != null) {
      this.withStaticIPAMConfig(instance.getStaticIPAMConfig());
      this.withType(instance.getType());
      this.withStaticIPAMConfig(instance.getStaticIPAMConfig());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IPAMConfigFluent<?> fluent;
  Boolean validationEnabled;
  public IPAMConfig build() {
    IPAMConfig buildable = new IPAMConfig(fluent.buildStaticIPAMConfig(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
